@@ -1,14 +1,13 @@
 from __future__ import (unicode_literals, absolute_import)
-from nose.tools import *  # noqa
 from . import osmapi_tests
 
 
 class TestOsmApiNode(osmapi_tests.TestOsmApi):
     def test_Capabilities(self):
-        self._conn_mock()
+        self._session_mock()
 
         result = self.api.Capabilities()
-        assert_equals(result, {
+        self.assertEquals(result, {
             'area': {'maximum': 0.25},
             'changesets': {'maximum_elements': 50000.0},
             'status': {
